@@ -2,7 +2,7 @@
 #-------------------------------------------------------------------------
 # Module: Gbook
 # Author: Jos (josvd@live.nl)
-# Version: 1.0
+# Version: 1.0.1
 #
 #-------------------------------------------------------------------------
 # CMS - CMS Made Simple is (c) 2009 by Ted Kulp (wishy@cmsmadesimple.org)
@@ -43,7 +43,7 @@ class Gbook extends CMSModule
 
 	function GetVersion()
 	{
-		return '1.0';
+		return '1.0.1';
 	}
 
 	function GetHelp()
