@@ -210,12 +210,19 @@ switch ($params['mode'])
 				$file = $_FILES[$fieldname];
 				$filecontent = file_get_contents($file['tmp_name']);
 				$filecontent = str_replace("\r\n", "\n", $filecontent);
+				$filecontent = str_replace("\n\r", "\n", $filecontent);
 				$filecontent = str_replace(';;', ';"";', $filecontent);
 				$csvdata = str_getcsv($filecontent, "\n"); //parse the rows
 				foreach($csvdata as $row) 
 				{
 					$csvrow = str_getcsv($row, ";"); //parse the items in rows
-					$result = $db->Execute($query, array($params['gbookid'], stripslashes($csvrow[0]), stripslashes($csvrow[1]), stripslashes($csvrow[2]), stripslashes($csvrow[3]), $csvrow[4], $csvrow[5]));
+					for ($i = 0; $i < 4; $i++) {
+						$csvrow[$i] = stripslashes($csvrow[$i]);
+						$csvrow[$i] = html_entity_decode($csvrow[$i],ENT_QUOTES);
+						$csvrow[$i] = utf8_encode($csvrow[$i]);
+						if ( $i < 3 ) $csvrow[$i] = strip_tags($csvrow[$i]);
+					}
+					$result = $db->Execute($query, array($params['gbookid'], $csvrow[0], $csvrow[1],$csvrow[2], $csvrow[3], $csvrow[4], $csvrow[5]));
 				}
 			}
 			
