@@ -159,19 +159,17 @@ switch ($params['mode'])
 
 if ( !empty($item) )
 {
-	$themeObject =& $gCms->variables['admintheme'];
-
 	$smarty->assign('gbook_name_label', $this->Lang('name'));
-	$smarty->assign('gbook_name_input', $this->CreateInputText($id, 'name', $item->name, 40, 255));
+	$smarty->assign('gbook_name_input', $this->CreateInputText($id, 'name', html_entity_decode($item->name,ENT_QUOTES), 40, 255));
 
 	$smarty->assign('gbook_email_label', $this->Lang('email'));
-	$smarty->assign('gbook_email_input', $this->CreateInputText($id, 'email', $item->email, 40, 255));
+	$smarty->assign('gbook_email_input', $this->CreateInputText($id, 'email', html_entity_decode($item->email,ENT_QUOTES), 40, 255));
 
 	$smarty->assign('gbook_title_label', $this->Lang('title'));
-	$smarty->assign('gbook_title_input', $this->CreateInputText($id, 'title', $item->title, 40, 255));
+	$smarty->assign('gbook_title_input', $this->CreateInputText($id, 'title', html_entity_decode($item->title,ENT_QUOTES), 40, 255));
 
 	$smarty->assign('gbook_message_label', $this->Lang('message'));
-	$smarty->assign('gbook_message_input', $this->CreateTextArea(false, $id, $item->rawmessage, 'message', '', $id . 'message'));
+	$smarty->assign('gbook_message_input', $this->CreateTextArea(false, $id, html_entity_decode($item->rawmessage,ENT_QUOTES), 'message', '', $id . 'message'));
 
 	$spamrate = Gbook_utils::b8_exec('Classify', $item->title . ' ' . $item->rawmessage);
 	$smarty->assign('spamrate', $this->Lang('spamrate') . ': ' . Gbook_utils::format_rating($spamrate));
@@ -180,14 +178,14 @@ if ( !empty($item) )
 	{
 		// marked as HAM
 		$smarty->assign('approvelink', $this->CreateLink($id, 'edititem', $returnid,
-				    $themeObject->DisplayImage('icons/system/false.gif', $this->Lang('deletefromham'),'','','systemicon') . ' ' . $this->Lang('deletefromham'),
+				    '<img src="../modules/Gbook/images/nospam.gif" class="systemicon" alt="' . $this->Lang('deletefromham') . '"> ' . $this->Lang('deletefromham'),
 				    array ('gbookid' => $params['gbookid'], 'entryid' => $item->entry_id, 'mode'=>'deletefromham')));
 	}
 	elseif ( $item->approved == 2 )
 	{
 		// marked as SPAM
 		$smarty->assign('approvelink', $this->CreateLink($id, 'edititem', $returnid,
-				    $themeObject->DisplayImage('icons/system/false.gif', $this->Lang('deletefromspam'),'','','systemicon') . ' ' . $this->Lang('deletefromspam'),
+				    '<img src="../modules/Gbook/images/nospam.gif" class="systemicon" alt="' . $this->Lang('deletefromspam') . '"> ' . $this->Lang('deletefromspam'),
 				    array ('gbookid' => $params['gbookid'], 'entryid' => $item->entry_id, 'mode'=>'deletefromspam')));
 	}
 	else	
@@ -195,11 +193,11 @@ if ( !empty($item) )
 		// not approved
 		$smarty->assign('approvelink', 
 						$this->CreateLink($id, 'edititem', $returnid,
-				    $themeObject->DisplayImage('icons/system/true.gif', $this->Lang('saveasham'),'','','systemicon') . ' ' . $this->Lang('saveasham'),
+				    '<img src="../modules/Gbook/images/check.png" class="systemicon" alt="' . $this->Lang('saveasham') . '"> ' . $this->Lang('saveasham'),
 				    array ('gbookid' => $params['gbookid'], 'entryid' => $item->entry_id, 'mode'=>'saveasham'))
 						. ' &nbsp; ' .
 						$this->CreateLink($id, 'edititem', $returnid,
-				    $themeObject->DisplayImage('icons/system/false.gif', $this->Lang('saveasspam'),'','','systemicon') . ' ' . $this->Lang('saveasspam'),
+				    '<img src="../modules/Gbook/images/nospam.gif" class="systemicon" alt="' . $this->Lang('saveasspam') . '"> ' . $this->Lang('saveasspam'),
 				    array ('gbookid' => $params['gbookid'], 'entryid' => $item->entry_id, 'mode'=>'saveasspam'))
 					);
 	}
