@@ -77,6 +77,11 @@ if( $_SERVER['REQUEST_METHOD'] == 'POST' && isset($params['submit']) )
 	$receivedtoken = explode('-', $params['token']);
 	if ( array_key_exists($receivedtoken[0], $token) && $receivedtoken[1] == md5($gbook['gbook_id'] . $token[$receivedtoken[0]]) )
 	{
+		$fields = array('name', 'email', 'title', 'message');
+		foreach ($fields as $field)
+		{
+			$params[$field] = html_entity_decode($params[$field],ENT_QUOTES);
+		}
 		$addentry = Gbook_utils::AddEntry($gbook['gbook_id'], $params['name'], $params['email'], $params['title'], $params['message'], $params['notify']);
 
 		if ( is_array($addentry) && key($addentry) == 'entry added' )
