@@ -81,6 +81,7 @@ $lang['max_spamrate_notify'] = 'Maximum spamrating for sending a notification to
 $lang['max_spamrate_notify_help'] = 'between 0 and 1, default 0.9. Higher value will increase the chance of getting notifications of spam entries.';
 $lang['max_spamrate_save'] = 'Maximum spamrating for saving a new entry';
 $lang['max_spamrate_save_help'] = 'between 0 and 1, default 0.9. Lower value will increase the chance of losing legitimate entries.';
+$lang['badwords'] = 'Filter bad words (comma separated)';
 $lang['optionsupdated'] = 'The options were successfully updated.';
 
 
@@ -110,7 +111,7 @@ Check it on: {root_url}';
 
 
 //Help
-$lang['help_action'] = 'Possible values: <ul><li>\'default\' - for displaying the guestbook entries</li><li>\'form\' - for displaying a form</li><li>\'detail\' - for displaying a single entry, e.g. as search result</li><ul>';
+$lang['help_action'] = 'Possible values: <ul><li>\'default\' - for displaying the guestbook entries</li><li>\'form\' - for displaying a form</li><li>\'detail\' - for displaying a single entry, e.g. as search result</li></ul>';
 $lang['help_alias'] = 'Use another guestbook than the default one. Check the Guestbooks-tab, column \'Tags\', to see which aliases can be used.';
 $lang['help_entryid'] = 'Use this parameter along with <code>action=\'detail\'</code> if you want to display only one guestbook entry. To get the latest entry, use <code>entryid=-1</code>';
 $lang['help_template'] = 'Use another template than the default one. Note that templates must be of the proper type, in accordance with the action parameter.';
@@ -155,6 +156,6 @@ Users must belong to a group with the \'Gbook: Modify\' permission to be able to
 </ul>
 
 <h3>Feedback</h3>
-<p>If you enjoy this module, use it on a commercial website or would like to encourage future development, you might consider just a small donation.<br />Or leave a message in the <a href="http://forum.cmsmadesimple.org/">Gbook forum topic</a>. Any kind of feedback will be much appreciated.</p>
+<p>If you enjoy this module, use it on a commercial website or would like to encourage future development, you might consider just a small donation.<br />Or leave a message in the <a href="http://forum.cmsmadesimple.org/viewtopic.php?f=7&t=64460">Gbook forum topic</a>. Any kind of feedback will be much appreciated.</p>
 ';
 ?>
