@@ -107,10 +107,10 @@ class Gbook_utils
 				
 				$onerow->entry_id = $row['entry_id'];
 				$onerow->gbook_id = $row['gbook_id'];
-				$onerow->name = htmlspecialchars($row['name']);
-				$onerow->email = $row['email'];
-				$onerow->title = $row['title'];
-				$onerow->message = self::nl2pnbr($row['message']);
+				$onerow->name = cms_htmlentities($row['name']);
+				$onerow->email = cms_htmlentities($row['email']);
+				$onerow->title = cms_htmlentities($row['title']);
+				$onerow->message = self::nl2pnbr(cms_htmlentities($row['message']));
 				if ( $row['allow_smilies'] )
 				{
 					$onerow->message = self::replace_smileys($onerow->message);
@@ -164,10 +164,10 @@ class Gbook_utils
 			$onerow = new stdClass();
 			$onerow->entry_id = $row['entry_id'];
 			$onerow->gbook_id = $row['gbook_id'];
-			$onerow->name = htmlspecialchars($row['name']);
-			$onerow->email = $row['email'];
-			$onerow->title = $row['title'];
-			$onerow->message = self::nl2pnbr($row['message']);
+			$onerow->name = cms_htmlentities($row['name']);
+			$onerow->email = cms_htmlentities($row['email']);
+			$onerow->title = cms_htmlentities($row['title']);
+			$onerow->message = self::nl2pnbr(cms_htmlentities($row['message']));
 			if ( $row['allow_smilies'] )
 			{
 				$onerow->message = self::replace_smileys($onerow->message);
@@ -310,95 +310,67 @@ class Gbook_utils
 
 	
 	public static function EditEntry($entry_id, $gbook_id, $name, $email, $title, $message, $notify, $active) {
-		$ip = $_SERVER['REMOTE_ADDR'];
-		
-		// check for valid input
-		$gbooks = self::GetGbooks($gbook_id, false);
-		if ( empty($gbooks) )
+		// only admin, so no need to check for valid input, just strip tags
+		$name = strip_tags($name);
+		$email = strip_tags($email);
+		$title = strip_tags($title);
+
+		$db = cmsms()->GetDB();
+		$query = "UPDATE " . cms_db_prefix() . "module_gbook_entries SET
+								gbook_id = ?,
+								name = ?,
+								email = ?,
+								title = ?,
+								message = ?,
+								notify = ?,
+								modified_date = NOW(),
+								active = ?
+							WHERE
+								entry_id = ?";
+		$result = $db->Execute($query, array(
+				$gbook_id, 
+				$name, 
+				$email, 
+				$title, 
+				$message, 
+				$notify,
+				$active,
+				$entry_id
+		));
+		if ( $result )
 		{
-			$errors[] = 'gbook_id';
-		}
-		else
-		{
-			$gbook = $gbooks[0];
-			$required_fields = explode(',', $gbook['required_fields'] . ',message');
-			$name = strip_tags($name);
-			$email = strip_tags($email);
-			$title = strip_tags($title);
-			if ( in_array('name',  $required_fields) && empty($name) ) $errors[] = 'name';
-			if ( in_array('email', $required_fields) && !is_email($email, false) ) $errors[] = 'email';
-			if ( in_array('title', $required_fields) && empty($title) ) $errors[] = 'title';
-			if ( empty($message) ) $errors[] = 'message';			
-		}
-		
-		if ( !empty($errors) )
-		{
-			$error = implode(', ',$errors);
-			return lang('missingparams') . ': ' . $error;
-		}
-		else
-		{
-			$db = cmsms()->GetDB();
-			$query = "UPDATE " . cms_db_prefix() . "module_gbook_entries SET
-									gbook_id = ?,
-									name = ?,
-									email = ?,
-									title = ?,
-									message = ?,
-									notify = ?,
-									modified_date = NOW(),
-									activation_code = ?,
-									active = ?
-								WHERE
-									entry_id = ?";
-			$result = $db->Execute($query, array(
-					$gbook_id, 
-					$name, 
-					$email, 
-					$title, 
-					$message, 
-					$notify,
-					'',
-					$active,
-					$entry_id
-			));
-			if ( $result )
+			$mod = cms_utils::get_module('Gbook');
+			$params['entry_id'] = $entry_id;
+			$params['gbook_id'] = $gbook_id;
+			$params['name'] = $name;
+			$params['email'] = $email;
+			$params['title'] = $title;
+			$params['message'] = $message;
+			$params['notify'] = $notify;
+			$params['active'] = $active;
+			$mod->SendEvent('Gbook_entry_edited', $params);
+
+			//Update search index
+			$search = cms_utils::get_module('Search');
+			if ( $search != false )
 			{
 				if ( $active == 1 )
 				{
-					$params['entry_id'] = $entry_id;
-					$params['gbook_id'] = $gbook_id;
-					$params['name'] = $name;
-					$params['email'] = $email;
-					$params['title'] = $title;
-					$params['message'] = $message;
-					$params['notify'] = $notify;
-					$params['active'] = $active;
-					$mod = cms_utils::get_module('Gbook');
-					$mod->SendEvent('Gbook_entry_edited', $params);
+					$search->AddWords($mod->GetName(), $entry_id, 'entry', $params['title'] . ' ' . $params['message']);
 				}
-				
-				//Update search index
-				$search = cms_utils::get_module('Search');
-				if ( $search != false )
+				else
 				{
-					if ( $active == 1 )
-					{
-						$search->AddWords($mod->GetName(), $entry_id, 'entry', $params['title'] . ' ' . $params['message']);
-					}
-					else
-					{
-						$search->DeleteWords($mod->GetName(), $entry_id, 'entry');
-					}
+					$search->DeleteWords($mod->GetName(), $entry_id, 'entry');
 				}
-				return $params;
-			}
-			else
-			{
-				echo 'ERROR: ' . __LINE__ . ' » ' . mysql_error();
-				exit();
 			}
+			return true;
 		}
+		else
+		{
+			echo 'ERROR: ' . __LINE__ . ' » ' . mysql_error();
+			exit();
+		}
+
 	}
 
 	
@@ -469,11 +441,12 @@ class Gbook_utils
 	
 	public static function replace_smileys($text) {
 		$smileys = self::GetSmileys(false);	
+		$text = ' ' . $text . ' ';
 		foreach ( $smileys as $smiley )
 		{
 			$text = str_replace(' '.$smiley['smiley_code'].' ', ' <img src="'.$smiley['smiley_path'].'" alt="" /> ', $text);
 		}
-		$text = str_replace('  ' , ' ', $text);
+		$text = trim(str_replace('  ' , ' ', $text));
 		return $text;
 	}
 
